# utils

Implements simple extensions to the core python libraries.

To install:

```
pip install utils-nuuuwan
```

To install development version (which might have more features, but also be
less stable):

```
pip install -i https://test.pypi.org/simple/ utils-nuuuwan
```
